pub struct SearchRequest<S, C>where
S: Service,{ /* private fields */ }Implementations
Sourceimpl<S, C> SearchRequest<S, C>
impl<S, C> SearchRequest<S, C>
Sourcepub fn iban_detection(self, enable: bool) -> SearchRequest<S, C>
pub fn iban_detection(self, enable: bool) -> SearchRequest<S, C>
If IBAN detection is enabled and the first value of a [SearchFilter::Term] is detected
to be a possible prefix of an IBAN that contains a national bank code,
the result might contain additional connections that match that bank code.
Sourcepub fn limit(self, limit: impl Into<Option<usize>>) -> SearchRequest<S, C>
pub fn limit(self, limit: impl Into<Option<usize>>) -> SearchRequest<S, C>
Limit the number of results.
Sourcepub fn details(
self,
details: impl IntoIterator<Item = Details>,
) -> SearchRequest<S, C>
pub fn details( self, details: impl IntoIterator<Item = Details>, ) -> SearchRequest<S, C>
Details to contain in search results.